==> aws-cdk-lib-2.51.1-sources.jar: software/amazon/awscdk/services/codedeploy/ServerDeploymentConfig.java <==
package software.amazon.awscdk.services.codedeploy;

/**
 * A custom Deployment Configuration for an EC2/on-premise Deployment Group.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * ServerDeploymentGroup deploymentGroup = ServerDeploymentGroup.Builder.create(this, "CodeDeployDeploymentGroup")
 *         .deploymentConfig(ServerDeploymentConfig.ALL_AT_ONCE)
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-11-18T21:59:09.913Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_codedeploy.ServerDeploymentConfig")
public class ServerDeploymentConfig extends software.amazon.awscdk.services.codedeploy.BaseDeploymentConfig implements software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig {

    protected ServerDeploymentConfig(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ServerDeploymentConfig(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        ALL_AT_ONCE = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codedeploy.ServerDeploymentConfig.class, "ALL_AT_ONCE", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig.class));
        HALF_AT_A_TIME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codedeploy.ServerDeploymentConfig.class, "HALF_AT_A_TIME", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig.class));
        ONE_AT_A_TIME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codedeploy.ServerDeploymentConfig.class, "ONE_AT_A_TIME", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig.class));
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public ServerDeploymentConfig(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codedeploy.ServerDeploymentConfigProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * Import a custom Deployment Configuration for an EC2/on-premise Deployment Group defined either outside the CDK app, or in a different region.
     * <p>
     * @return a Construct representing a reference to an existing custom Deployment Configuration
     * @param scope the parent Construct for this new Construct. This parameter is required.
     * @param id the logical ID of this new Construct. This parameter is required.
     * @param serverDeploymentConfigName the properties of the referenced custom Deployment Configuration. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig fromServerDeploymentConfigName(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull java.lang.String serverDeploymentConfigName) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.codedeploy.ServerDeploymentConfig.class, "fromServerDeploymentConfigName", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(serverDeploymentConfigName, "serverDeploymentConfigName is required") });
    }

    /**
     * The CodeDeployDefault.AllAtOnce predefined deployment configuration for EC2/on-premises compute platform.
     * <p>
     * @see <a href="https://docs.aws.amazon.com/codedeploy/latest/userguide/deployment-configurations.html#deployment-configuration-server">https://docs.aws.amazon.com/codedeploy/latest/userguide/deployment-configurations.html#deployment-configuration-server</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig ALL_AT_ONCE;

    /**
     * The CodeDeployDefault.HalfAtATime predefined deployment configuration for EC2/on-premises compute platform.
     * <p>
     * @see <a href="https://docs.aws.amazon.com/codedeploy/latest/userguide/deployment-configurations.html#deployment-configuration-server">https://docs.aws.amazon.com/codedeploy/latest/userguide/deployment-configurations.html#deployment-configuration-server</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig HALF_AT_A_TIME;

    /**
     * The CodeDeployDefault.OneAtATime predefined deployment configuration for EC2/on-premises compute platform.
     * <p>
     * @see <a href="https://docs.aws.amazon.com/codedeploy/latest/userguide/deployment-configurations.html#deployment-configuration-server">https://docs.aws.amazon.com/codedeploy/latest/userguide/deployment-configurations.html#deployment-configuration-server</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig ONE_AT_A_TIME;

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.codedeploy.ServerDeploymentConfig}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.codedeploy.ServerDeploymentConfig> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.codedeploy.ServerDeploymentConfigProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.codedeploy.ServerDeploymentConfigProps.Builder();
        }

        /**
         * The physical, human-readable name of the Deployment Configuration.
         * <p>
         * Default: - automatically generated name
         * <p>
         * @return {@code this}
         * @param deploymentConfigName The physical, human-readable name of the Deployment Configuration. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder deploymentConfigName(final java.lang.String deploymentConfigName) {
            this.props.deploymentConfigName(deploymentConfigName);
            return this;
        }

        /**
         * Minimum number of healthy hosts.
         * <p>
         * @return {@code this}
         * @param minimumHealthyHosts Minimum number of healthy hosts. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder minimumHealthyHosts(final software.amazon.awscdk.services.codedeploy.MinimumHealthyHosts minimumHealthyHosts) {
            this.props.minimumHealthyHosts(minimumHealthyHosts);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.codedeploy.ServerDeploymentConfig}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.codedeploy.ServerDeploymentConfig build() {
            return new software.amazon.awscdk.services.codedeploy.ServerDeploymentConfig(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> aws-cdk-lib-2.130.0-sources.jar: software/amazon/awscdk/services/codedeploy/ServerDeploymentConfig.java <==
package software.amazon.awscdk.services.codedeploy;

/**
 * A custom Deployment Configuration for an EC2/on-premise Deployment Group.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * ServerDeploymentGroup deploymentGroup = ServerDeploymentGroup.Builder.create(this, "CodeDeployDeploymentGroup")
 *         .deploymentConfig(ServerDeploymentConfig.ALL_AT_ONCE)
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-02-23T02:06:29.770Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_codedeploy.ServerDeploymentConfig")
public class ServerDeploymentConfig extends software.amazon.awscdk.services.codedeploy.BaseDeploymentConfig implements software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig {

    protected ServerDeploymentConfig(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ServerDeploymentConfig(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        ALL_AT_ONCE = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codedeploy.ServerDeploymentConfig.class, "ALL_AT_ONCE", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig.class));
        HALF_AT_A_TIME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codedeploy.ServerDeploymentConfig.class, "HALF_AT_A_TIME", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig.class));
        ONE_AT_A_TIME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codedeploy.ServerDeploymentConfig.class, "ONE_AT_A_TIME", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig.class));
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public ServerDeploymentConfig(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codedeploy.ServerDeploymentConfigProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * Import a custom Deployment Configuration for an EC2/on-premise Deployment Group defined either outside the CDK app, or in a different region.
     * <p>
     * @return a Construct representing a reference to an existing custom Deployment Configuration
     * @param scope the parent Construct for this new Construct. This parameter is required.
     * @param id the logical ID of this new Construct. This parameter is required.
     * @param serverDeploymentConfigName the properties of the referenced custom Deployment Configuration. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig fromServerDeploymentConfigName(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull java.lang.String serverDeploymentConfigName) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.codedeploy.ServerDeploymentConfig.class, "fromServerDeploymentConfigName", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(serverDeploymentConfigName, "serverDeploymentConfigName is required") });
    }

    /**
     * The CodeDeployDefault.AllAtOnce predefined deployment configuration for EC2/on-premises compute platform.
     * <p>
     * @see <a href="https://docs.aws.amazon.com/codedeploy/latest/userguide/deployment-configurations.html#deployment-configuration-server">https://docs.aws.amazon.com/codedeploy/latest/userguide/deployment-configurations.html#deployment-configuration-server</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig ALL_AT_ONCE;

    /**
     * The CodeDeployDefault.HalfAtATime predefined deployment configuration for EC2/on-premises compute platform.
     * <p>
     * @see <a href="https://docs.aws.amazon.com/codedeploy/latest/userguide/deployment-configurations.html#deployment-configuration-server">https://docs.aws.amazon.com/codedeploy/latest/userguide/deployment-configurations.html#deployment-configuration-server</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig HALF_AT_A_TIME;

    /**
     * The CodeDeployDefault.OneAtATime predefined deployment configuration for EC2/on-premises compute platform.
     * <p>
     * @see <a href="https://docs.aws.amazon.com/codedeploy/latest/userguide/deployment-configurations.html#deployment-configuration-server">https://docs.aws.amazon.com/codedeploy/latest/userguide/deployment-configurations.html#deployment-configuration-server</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig ONE_AT_A_TIME;

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.codedeploy.ServerDeploymentConfig}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.codedeploy.ServerDeploymentConfig> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.codedeploy.ServerDeploymentConfigProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.codedeploy.ServerDeploymentConfigProps.Builder();
        }

        /**
         * The physical, human-readable name of the Deployment Configuration.
         * <p>
         * Default: - automatically generated name
         * <p>
         * @return {@code this}
         * @param deploymentConfigName The physical, human-readable name of the Deployment Configuration. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder deploymentConfigName(final java.lang.String deploymentConfigName) {
            this.props.deploymentConfigName(deploymentConfigName);
            return this;
        }

        /**
         * Minimum number of healthy hosts.
         * <p>
         * @return {@code this}
         * @param minimumHealthyHosts Minimum number of healthy hosts. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder minimumHealthyHosts(final software.amazon.awscdk.services.codedeploy.MinimumHealthyHosts minimumHealthyHosts) {
            this.props.minimumHealthyHosts(minimumHealthyHosts);
            return this;
        }

        /**
         * @return a newly built instance of {@link software.amazon.awscdk.services.codedeploy.ServerDeploymentConfig}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.codedeploy.ServerDeploymentConfig build() {
            return new software.amazon.awscdk.services.codedeploy.ServerDeploymentConfig(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
